#!/usr/bin/env python

import os
import sys
import yaml 
import random 
import datetime
from glob import glob
from tqdm import tqdm


''' DEFAULT CONFIG OPTIONS (YAML) '''
def join(loader, node):
    seq = loader.construct_sequence(node)
    return ''.join([str(i) for i in seq])

yaml.add_constructor('!join', join)
cfg = yaml.load(open(glob('build_*.yml')[0]), Loader=yaml.Loader)

''' VARIABLES '''
jsonDir = cfg['jsonDir']
paragraphs = 'article_random_paragraph.txt'
tag = 'demo-a'

''' BUILD JSON ARTICLES '''
if len(sys.argv) != 3:
    print('Usage: {} NUM TAG'.format(sys.argv[0]))
    print('Example: {} 100 demo-a'.format(sys.argv[0]))
    sys.exit(1)

try:   
	articles = int(sys.argv[1])
	tag = sys.argv[2]
except ValueError as err:
    print('Error: "{}" not valid. Nothing done. Exiting.'.format(sys.argv[1]))
    print('Example: {} 100 demo-a'.format(sys.argv[0]))
    sys.exit(1)
    
with open(paragraphs) as f:
    p = f.readlines()
    
p = [i.strip() for i in p if i.strip()]      
    
if not os.path.isdir(f'{jsonDir}/{tag}'):
	os.makedirs(f'{jsonDir}/{tag}')

print(f'Building article json files...')
jdate = datetime.datetime.now().strftime('%Y-%m-%d')
for i in tqdm(range(articles)):    
    a, i = [], i+1
    for pr in range(random.randrange(5, 15)):         
        a.append(random.choice(p))
    x = f'%0{len(str(articles))}d' % i
    with open(f'{jsonDir}/{tag}/article_{x}.json', 'w') as f:
        print('{', file = f)
        print(f'    "filename": "article_{x}",', file = f)
        title = a[0][3:random.randrange(7,10)]
        title = ' '.join(a[0].split()[3:random.randrange(7,10)]).title().replace('.', '')
        print(f'    "title": "{title}",', file = f)
        print(f'    "website": "demo.test",', file = f)
        print(f'    "url": "",', file = f)
        print(f'    "date": "{jdate}",', file = f)
        print(f'    "tags": ["article", "demo", "{tag}"],', file = f)               
        print(f'    "lines": {{', file = f)        
        num = 1
        print(f'        "%03d": {{' % num, file = f)
        print(f'            "number": {num},', file = f)        
        print(f'            "bold": true,', file = f)
        print(f'            "line-height": "normal",', file = f)
        print(f'            "text": "{title}"', file = f)
        print('        },', file = f)
        for pa in a: 
            num += 1
            print(f'        "%03d": {{' % num, file = f)
            print(f'            "number": {num},', file = f)            
            print(f'            "bold": false,', file = f)
            print(f'            "line-height": "normal",', file = f)
            print(f'            "text": "{pa}"', file = f)
            if num != len(a)+1:
                print('        },', file = f)           
            else:
                print('        }', file = f)           
        print('    }', file = f)
        print('}', file = f)        


with open('README') as f:
    readme = f.readlines()

title = cfg['site_defaults']['aboutdemo']
with open(f'{jsonDir}/{tag}/article_readme.json', 'w') as f:
    print('{', file = f)
    print(f'    "filename": "article_readme",', file = f)
    print(f'    "title": "{title}",', file = f)
    print(f'    "website": "demo.test",', file = f)
    print(f'    "url": "",', file = f)
    print(f'    "date": "{jdate}",', file = f)
    print(f'    "tags": ["article", "demo", "readme"],', file = f)               
    print(f'    "lines": {{', file = f)        
    num = 1
    print(f'        "%03d": {{' % num, file = f)
    print(f'            "number": {num},', file = f)        
    print(f'            "bold": true,', file = f)
    print(f'            "line-height": "normal",', file = f)
    print(f'            "text": "{title}"', file = f)
    print('        },', file = f)
    for rm in readme: 
        num += 1
        print(f'        "%03d": {{' % num, file = f)
        print(f'            "number": {num},', file = f)            
        print(f'            "bold": false,', file = f)
        print(f'            "line-height": "normal",', file = f)
        rm = rm.strip().replace('"', '\\"')
        print(f'            "text": "{rm}"', file = f)
        if num != len(readme)+1:
            print('        },', file = f)           
        else:
            print('        }', file = f)           
    print('    }', file = f)
    print('}', file = f)        
