#!/usr/bin/env python
# -*- coding: utf-8 -*

import os
import sys
import yaml
import json
import sqlite3
import datetime
import jinja2
from glob import glob
from flask import Flask
app = Flask(__name__)

scriptname = os.path.basename(sys.argv[0])
scriptversion='0.1.0'

''' DEFAULT CONFIG OPTIONS (YAML) '''
def join(loader, node):
    seq = loader.construct_sequence(node)
    return ''.join([str(i) for i in seq])

yaml.add_constructor('!join', join) 
cfg = yaml.load(open(glob('build_*.yml')[0]), Loader=yaml.Loader)
cfg['site_defaults']['year'] = datetime.date.today().year
default = cfg['site_defaults']

''' PROD -OR- DEV '''
print('Initializing environment...')
if default['prod'] and default['prod'] == 'prod':
    default['css'] = default['css']['prod']
    default['css_script'] = default['css_script']['prod']
    default['javascript'] = default['javascript']['prod']
else:
    default['css'] = default['css']['dev']
    default['css_script'] = default['css_script']['dev']

with open('%s_browse.json' % cfg['baseName']) as bjson:
    bkeys = json.loads(''.join(bjson.readlines()))   

''' SEARCH APP '''
@app.route('/')
def home():
    return 'Welcome home!'

@app.route('/search/')
@app.route('/search/<string:search_text>')
def search(search_text = 'demo'):
    sql_search = 'select id, title, article, slug from site_search where article like ?'
    search_results = {}
    search_text = search_text.strip()
    if isinstance(search_text, str):
        conn = sqlite3.connect('%s.db' % cfg['baseName'])
        c = conn.cursor()
        results = c.execute(sql_search, ('%%%s%%' % search_text,)).fetchall()
        conn.close()
        if results:
            for r in results:
                findx = r[2].lower().find(search_text.lower())
                search_snip = {
                    'pre': r[2][findx - 50:findx],
                    'text': r[2][findx:findx+len(search_text)],                         
                    'post': r[2][findx+len(search_text):findx+len(search_text) + (50 - len(search_text))]
                }
                search_results[r[0]] = {
                    'id': r[0],
                    'title': r[1],
                    'article': r[2],
                    'slug': r[3],
                    'snip': search_snip,
                }
        env = jinja2.Environment(
            loader = jinja2.FileSystemLoader(cfg['j2Dir'], followlinks=True),
            autoescape = jinja2.select_autoescape(['j2'])
        )
        template_html = env.get_template('search.html.j2')
        search_html = template_html.render(default = default, search_text = search_text, search_results = search_results, bkeys = bkeys).splitlines()
        final_html = [ line for line in search_html if line.strip() ]
    return '\n'.join(final_html)

if __name__ == '__main__': 
    app.run(host='127.0.0.1', port=8000, debug=True)
